==> visual-third-party-0.4.3-lg-sources.jar: com/tenqube/visual_third/ui/VisualPermissionActivity.java <==
package com.tenqube.visual_third.ui;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.text.Html;
import android.view.View;
import android.view.Window;
import android.widget.TextView;

import com.tenqube.visual_third.R;
import com.tenqube.visual_third.util.Utils;

/**
 * An example full-screen activity that shows and hides the system UI (i.e.
 * status bar and navigation/system bar) with user interaction.
 */
public class VisualPermissionActivity extends Activity {

    public static final int REQ_CODE_OVERLAY_PERMISSION = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
        setContentView(R.layout.activity_visual_permission);

        TextView content = findViewById(R.id.content);
        String contentText = "<font color=\"#000000\">모바일 영수증 기능의 원활한 사용을 위해<br><b>다른 앱 위에 표시</b> 권한이 필요합니다.</font>";

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
            content.setText(Html.fromHtml(contentText, Html.FROM_HTML_MODE_COMPACT));
        } else {
            content.setText(Html.fromHtml(contentText));
        }

        findViewById(R.id.start).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                onObtainingPermissionOverlayWindow();
            }
        });

    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, final Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        switch (requestCode) {
            case REQ_CODE_OVERLAY_PERMISSION:
                setResult(RESULT_OK);
                finish();
                break;
        }
    }

    @TargetApi(Build.VERSION_CODES.M)
    public void onObtainingPermissionOverlayWindow() {
        Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION, Uri.parse("package:" + getApplication().getPackageName()));
        startActivityForResult(intent, REQ_CODE_OVERLAY_PERMISSION);
    }

    public static void startActivity(Activity activity, int requestCode) {

        try {
            Intent intent = new Intent(activity, VisualPermissionActivity.class);
            intent.addFlags( Intent.FLAG_ACTIVITY_CLEAR_TOP |
                    Intent.FLAG_ACTIVITY_SINGLE_TOP);
            activity.startActivityForResult(intent, requestCode);
        } catch (Exception e) {
        }
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        Utils.LOGD("onConfigurationChanged", "");
        finish();
    }

}

==> visual-third-party-1.3.3-lg-sources.jar: com/tenqube/visual_third/ui/VisualPermissionActivity.java <==
package com.tenqube.visual_third.ui;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.text.Html;
import android.view.View;
import android.view.Window;
import android.widget.TextView;

import com.tenqube.visual_third.R;
import com.tenqube.visual_third.util.Utils;

/**
 * An example full-screen activity that shows and hides the system UI (i.e.
 * status bar and navigation/system bar) with user interaction.
 */
public class VisualPermissionActivity extends Activity {

    public static final int REQ_CODE_OVERLAY_PERMISSION = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
        setContentView(R.layout.activity_visual_permission);

        TextView content = findViewById(R.id.content);
        String contentText = "<font color=\"#000000\">모바일 영수증 기능의 원활한 사용을 위해<br><b>다른 앱 위에 표시</b> 권한이 필요합니다.</font>";

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
            content.setText(Html.fromHtml(contentText, Html.FROM_HTML_MODE_COMPACT));
        } else {
            content.setText(Html.fromHtml(contentText));
        }

        findViewById(R.id.start).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                onObtainingPermissionOverlayWindow();
            }
        });

    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, final Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        switch (requestCode) {
            case REQ_CODE_OVERLAY_PERMISSION:
                setResult(RESULT_OK);
                finish();
                break;
        }
    }

    @TargetApi(Build.VERSION_CODES.M)
    public void onObtainingPermissionOverlayWindow() {
        Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION, Uri.parse("package:" + getApplication().getPackageName()));
        startActivityForResult(intent, REQ_CODE_OVERLAY_PERMISSION);
    }

    public static void startActivity(Activity activity, int requestCode) {

        try {
            Intent intent = new Intent(activity, VisualPermissionActivity.class);
            intent.addFlags( Intent.FLAG_ACTIVITY_CLEAR_TOP |
                    Intent.FLAG_ACTIVITY_SINGLE_TOP);
            activity.startActivityForResult(intent, requestCode);
        } catch (Exception e) {
        }
    }

    @Override
    protected void onRestoreInstanceState(Bundle savedInstanceState) {
        super.onRestoreInstanceState(savedInstanceState);
        Utils.LOGD("onRestoreInstanceState", "");
        finish();
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        Utils.LOGD("onConfigurationChanged", "");
        finish();
    }

}
